==> freegenius-0.0.48-py3-none-any.whl: freegenius/utils/ollama_models.py <==
ollama_models = (
    "gemma",
    "gemma:2b",
    "gemma:7b",
    "llama2",
    "llama2:7b",
    "llama2:13b",
    "llama2:70b",
    "mistral",
    "mistral:7b",
    "mixtral",
    "mixtral:8x7b",
    "llava",
    "llava:7b",
    "llava:13b",
    "llava:34b",
    "neural-chat",
    "codellama",
    "codellama:7b",
    "codellama:13b",
    "codellama:34b",
    "codellama:70b",
    "codellama:7b-python",
    "codellama:13b-python",
    "codellama:34b-python",
    "codellama:70b-python",
    "dolphin-mixtral",
    "dolphin-mixtral:8x7b",
    "mistral-openorca",
    "mistral-openorca:7b",
    "llama2-uncensored",
    "llama2-uncensored:7b",
    "llama2-uncensored:70b",
    "orca-mini",
    "orca-mini:3b",
    "orca-mini:7b",
    "orca-mini:13b",
    "orca-mini:70b",
    "phi",
    "phi:2.7b",
    "deepseek-coder",
    "deepseek-coder:1.3b",
    "deepseek-coder:6.7b",
    "deepseek-coder:33b",
    "dolphin-mistral",
    "dolphin-mistral:7b",
    "vicuna",
    "vicuna:7b",
    "vicuna:13b",
    "vicuna:33b",
    "wizard-vicuna-uncensored",
    "wizard-vicuna-uncensored:7b",
    "wizard-vicuna-uncensored:13b",
    "wizard-vicuna-uncensored:30b",
    "zephyr",
    "openhermes",
    "wizardcoder",
    "wizardcoder:33b",
    "wizardcoder:python",
    "wizardcoder:7b-python",
    "wizardcoder:13b-python",
    "wizardcoder:34b-python",
    "phind-codellama",
    "llama2-chinese",
    "llama2-chinese:7b",
    "llama2-chinese:13b",
    "tinyllama",
    "openchat",
    "qwen",
    "qwen:0.5b",
    "qwen:1.8b",
    "qwen:4b",
    "qwen:7b",
    "qwen:14b",
    "qwen:72b",
    "orca2",
    "orca2:7b",
    "orca2:13b",
    "falcon",
    "falcon:7b",
    "falcon:40b",
    "falcon:180b",
    "wizard-math",
    "wizard-math:7b",
    "wizard-math:13b",
    "wizard-math:70b",
    "nous-hermes",
    "nous-hermes:7b",
    "nous-hermes:13b",
    "nous-hermes:70b",
    "dolphin-phi",
    "starling-lm",
    "starling-lm:7b",
    "codeup",
    "starcoder",
    "starcoder:1b",
    "starcoder:3b",
    "starcoder:7b",
    "starcoder:15b",
    "medllama2",
    "yi",
    "yi:6b",
    "yi:34b",
    "wizardlm-uncensored",
    "everythinglm",
    "bakllava",
    "stable-code",
    "stable-beluga",
    "stable-beluga:7b",
    "stable-beluga:13b",
    "stable-beluga:70b",
    "solar",
    "sqlcoder",
    "sqlcoder:7b",
    "sqlcoder:15b",
    "sqlcoder:70b",
    "tinydolphin",
    "yarn-mistral",
    "nous-hermes2-mixtral",
    "nous-hermes2-mixtral:dpo",
    "nous-hermes2-mixtral:8x7b",
    "samantha-mistral",
    "stablelm-zephyr",
    "wizard-vicuna",
    "meditron",
    "meditron:7b",
    "meditron:70b",
    "magicoder",
    "yarn-llama2",
    "yarn-llama2:7b",
    "yarn-llama2:13b",
    "stablelm2",
    "nous-hermes2",
    "nous-hermes2:10.7b",
    "nous-hermes2:34b",
    "deepseek-llm",
    "deepseek-llm:7b",
    "deepseek-llm:67b",
    "open-orca-platypus2",
    "llama-pro",
    "codebooga",
    "nexusraven",
    "mistrallite",
    "goliath",
    "notux",
    "alfred",
    "megadolphin",
    "wizardlm",
    "wizardlm:7b",
    "wizardlm:13b",
    "wizardlm:30b",
    "wizardlm:70b",
    "xwinlm",
    "xwinlm:7b",
    "xwinlm:13b",
    "xwinlm:70b",
    "notus",
    "duckdb-nsql",
    "nomic-embed-text",
    "all-minilm",
    "starcoder2",
    "starcoder2:3b",
    "starcoder2:7b",
    "starcoder2:15b",
    "dolphincoder",
)

==> freegenius-0.0.84-py3-none-any.whl: freegenius/utils/ollama_models.py <==
ollama_models = (
    "gemma",
    "gemma:2b",
    "gemma:7b",
    "llama2",
    "llama2:7b",
    "llama2:13b",
    "llama2:70b",
    "mistral",
    "mistral:7b",
    "mixtral",
    "mixtral:8x7b",
    "neural-chat",
    "dolphin-mixtral",
    "dolphin-mixtral:8x7b",
    "mistral-openorca",
    "mistral-openorca:7b",
    "llama2-uncensored",
    "llama2-uncensored:7b",
    "llama2-uncensored:70b",
    "orca-mini",
    "orca-mini:3b",
    "orca-mini:7b",
    "orca-mini:13b",
    "orca-mini:70b",
    "phi",
    "phi:2.7b",
    "dolphin-mistral",
    "dolphin-mistral:7b",
    "vicuna",
    "vicuna:7b",
    "vicuna:13b",
    "vicuna:33b",
    "wizard-vicuna-uncensored",
    "wizard-vicuna-uncensored:7b",
    "wizard-vicuna-uncensored:13b",
    "wizard-vicuna-uncensored:30b",
    "zephyr",
    "openhermes",
    "llama2-chinese",
    "llama2-chinese:7b",
    "llama2-chinese:13b",
    "tinyllama",
    "openchat",
    "qwen",
    "qwen:0.5b",
    "qwen:1.8b",
    "qwen:4b",
    "qwen:7b",
    "qwen:14b",
    "qwen:72b",
    "orca2",
    "orca2:7b",
    "orca2:13b",
    "falcon",
    "falcon:7b",
    "falcon:40b",
    "falcon:180b",
    "wizard-math",
    "wizard-math:7b",
    "wizard-math:13b",
    "wizard-math:70b",
    "nous-hermes",
    "nous-hermes:7b",
    "nous-hermes:13b",
    "nous-hermes:70b",
    "dolphin-phi",
    "starling-lm",
    "starling-lm:7b",
    "medllama2",
    "yi",
    "yi:6b",
    "yi:34b",
    "wizardlm-uncensored",
    "everythinglm",
    "stable-beluga",
    "stable-beluga:7b",
    "stable-beluga:13b",
    "stable-beluga:70b",
    "solar",
    "tinydolphin",
    "yarn-mistral",
    "nous-hermes2-mixtral",
    "nous-hermes2-mixtral:dpo",
    "nous-hermes2-mixtral:8x7b",
    "samantha-mistral",
    "stablelm-zephyr",
    "wizard-vicuna",
    "meditron",
    "meditron:7b",
    "meditron:70b",
    "magicoder",
    "yarn-llama2",
    "yarn-llama2:7b",
    "yarn-llama2:13b",
    "stablelm2",
    "nous-hermes2",
    "nous-hermes2:10.7b",
    "nous-hermes2:34b",
    "deepseek-llm",
    "deepseek-llm:7b",
    "deepseek-llm:67b",
    "open-orca-platypus2",
    "llama-pro",
    "nexusraven",
    "mistrallite",
    "goliath",
    "notux",
    "alfred",
    "megadolphin",
    "wizardlm",
    "wizardlm:7b",
    "wizardlm:13b",
    "wizardlm:30b",
    "wizardlm:70b",
    "xwinlm",
    "xwinlm:7b",
    "xwinlm:13b",
    "xwinlm:70b",
    "notus",
    "duckdb-nsql",
    "command-r",
    # vision models
    "llava",
    "llava:7b",
    "llava:13b",
    "llava:34b",
    "bakllava",
    "bakllava:7b",
    # embeddings
    "nomic-embed-text",
    "all-minilm",
    "mxbai-embed-large",
    # code models
    "codebooga",
    "codebooga:34b",
    "wizardcoder",
    "wizardcoder:33b",
    "wizardcoder:python",
    "wizardcoder:7b-python",
    "wizardcoder:13b-python",
    "wizardcoder:34b-python",
    "phind-codellama",
    "phind-codellama:34b",
    "phind-codellama:34b-python",
    "codegemma",
    "codegemma:7b-instruct",
    "codegemma:7b-code",
    "codegemma:2b-code",
    "codellama",
    "codellama:7b-instruct",
    "codellama:13b-instruct",
    "codellama:34b-instruct",
    "codellama:70b-instruct",
    "codellama:7b-python",
    "codellama:13b-python",
    "codellama:34b-python",
    "codellama:70b-python",
    "codellama:7b-code",
    "codellama:13b-code",
    "codellama:34b-code",
    "codellama:70b-code",
    "stable-code",
    "stable-code:3b-code",
    "stable-code:3b-instruct",
    "codeup",
    "codeup:13b",
    "codeup:13b-llama2",
    "codeup:13b-llama2-chat",
    "deepseek-coder",
    "deepseek-coder:1.3b-instruct",
    "deepseek-coder:6.7b-instruct",
    "deepseek-coder:33b-instruct",
    "deepseek-coder:1.3b-base",
    "deepseek-coder:6.7b-base",
    "deepseek-coder:33b-base",
    "starcoder",
    "starcoder:1b",
    "starcoder:3b",
    "starcoder:7b",
    "starcoder:15b",
    "starcoder2",
    "starcoder2:3b",
    "starcoder2:7b",
    "starcoder2:15b",
    "dolphincoder",
    "dolphincoder:7b",
    "dolphincoder:15b",
    "sqlcoder",
    "sqlcoder:7b",
    "sqlcoder:15b",
    "sqlcoder:70b",
)
